@@ -153,6 +153,7 @@ def boost(queue_name,
           msg_expire_senconds: float = _Undefined,
           is_send_consumer_hearbeat_to_redis: bool = _Undefined,
           logger_prefix: str = _Undefined,
+          ding_talk_token: str = _Undefined,
           create_logger_file: bool = _Undefined,
           do_task_filtering: bool = _Undefined,
           task_filtering_expire_seconds: float = _Undefined,
@@ -193,6 +194,7 @@ def boost(queue_name,
     :param is_send_consumer_hearbeat_to_redis   是否将发布者的心跳发送到redis，有些功能的实现需要统计活跃消费者。因为有的中间件不是真mq。
     :param logger_prefix: 日志前缀，可使不同的消费者生成不同的日志前缀
     :param create_logger_file : 是否创建文件日志
+    :param ding_talk_token : 钉钉token
     :param do_task_filtering :是否执行基于函数参数的任务过滤
     :param task_filtering_expire_seconds:任务过滤的失效期，为0则永久性过滤任务。例如设置过滤过期时间是1800秒 ，
            30分钟前发布过1 + 2 的任务，现在仍然执行，
