@@ -286,6 +286,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
                  qps: float = 0, is_using_distributed_frequency_control=False,
                  msg_expire_senconds=0, is_send_consumer_hearbeat_to_redis=False,
                  logger_prefix='', create_logger_file=True, do_task_filtering=False,
+                 ding_talk_token=None,
                  task_filtering_expire_seconds=0,
                  is_do_not_run_by_specify_time_effect=False,
                  do_not_run_by_specify_time=('10:00:00', '22:00:00'),
@@ -426,6 +427,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
         self.logger = get_logger(logger_name, log_level_int=log_level, log_filename=f'{logger_name}.log' if create_logger_file else None,
                                  # log_file_handler_type=log_file_handler_type,
                                  formatter_template=funboost_config_deafult.ga_log_FORMATER_INDEX_FOR_CONSUMER_AND_PUBLISHER, )
+        self.alert = get_logger("alert", log_level_int=log_level, ding_talk_token=ding_talk_token)
         # self.logger.info(f'{self.__class__} 在 {current_queue__info_dict["where_to_instantiate"]}  被实例化')
 
         stdout_write(f'{time.strftime("%H:%M:%S")} "{current_queue__info_dict["where_to_instantiate"]}"  \033[0;37;44m此行 '
@@ -554,7 +556,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
                 if block:
                     return ___keep_circulating()
                 else:
-                    threading.Thread(target=___keep_circulating, daemon=True).start()
+                    threading.Thread(target=___keep_circulating).start()
 
             return __keep_circulating
 
@@ -824,7 +826,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
     def check_heartbeat_and_message_count(self):
         self._msg_num_in_broker = self.publisher_of_same_queue.get_message_count()
         if time.time() - self._last_timestamp_print_msg_num > 60:
-            if self._msg_num_in_broker != -1:
+            if self._msg_num_in_broker > 0:
                 self.logger.info(f'队列 [{self._queue_name}] 中还有 [{self._msg_num_in_broker}] 个任务')
             self._last_timestamp_print_msg_num = time.time()
         if self._msg_num_in_broker != 0:
@@ -866,8 +868,8 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
     def pause_consume(self):
         """设置队列为暂停消费状态"""
         self._stop_flag = 1
-        self.logger.info("==========停止消费===========")
-        #RedisMixin().redis_db_frame.set(self._redis_key_pause_flag, 1)
+        self.logger.warning(f'已设置 {self.queue_name} 队列中的任务为停止消费')
+        # RedisMixin().redis_db_frame.set(self._redis_key_pause_flag, 1)
 
     def continue_consume(self):
         """设置队列为继续消费状态"""
@@ -897,9 +899,12 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
             return
         publish_time = _get_publish_time(kw['body'])
         msg_expire_senconds_priority = self._get_priority_conf(kw, 'msg_expire_senconds')
-        if msg_expire_senconds_priority and time.time() - msg_expire_senconds_priority > publish_time:
+        dis = round(time.time() - publish_time, 4)
+        if dis > 5:
+            self.alert.info(f'延时报警：{self.queue_name} 消息发布时间距离现在 {dis} 秒,请检查服务器状态')
+        if msg_expire_senconds_priority and dis > msg_expire_senconds_priority:
             self.logger.warning(
-                f'消息发布时戳是 {publish_time} {kw["body"].get("publish_time_format", "")},距离现在 {round(time.time() - publish_time, 4)} 秒 ,'
+                f'消息发布时戳是 {publish_time} {kw["body"].get("publish_time_format", "")},距离现在 {dis} 秒 ,'
                 f'超过了指定的 {msg_expire_senconds_priority} 秒，丢弃任务')
             self._confirm_consume(kw)
             return 0
@@ -1052,12 +1057,12 @@ class ConcurrentModeDispatcher(LoggerMixin):
 
     def schedulal_task_with_no_block(self):
         if ConsumersManager.schedual_task_always_use_thread:
-            t = Thread(target=self.consumer.keep_circulating(1)(self.consumer._shedual_task), daemon=True)
+            t = Thread(target=self.consumer.keep_circulating(1)(self.consumer._shedual_task))
             ConsumersManager.schedulal_thread_to_be_join.append(t)
             t.start()
         elif self._concurrent_mode in [ConcurrentModeEnum.THREADING, ConcurrentModeEnum.ASYNC,
-                                         ConcurrentModeEnum.SINGLE_THREAD, ]:
-            t = Thread(target=self.consumer.keep_circulating(1)(self.consumer._shedual_task), daemon=True)
+                                       ConcurrentModeEnum.SINGLE_THREAD, ]:
+            t = Thread(target=self.consumer.keep_circulating(1)(self.consumer._shedual_task))
             ConsumersManager.schedulal_thread_to_be_join.append(t)
             t.start()
 
